@@ -23,6 +23,7 @@
 #' html <- markdown_html(md)
 #' xml <- markdown_xml(md)
 #' man <- markdown_man(md)
+#' tex <- markdown_latex(md)
 #' cm <- markdown_commonmark(md)
 markdown_html <- function(text, hardbreaks = FALSE, smart = FALSE, normalize = FALSE, sourcepos = FALSE){
   text <- enc2utf8(paste(text, collapse="\n"))
@@ -38,9 +39,9 @@ markdown_xml <- function(text, hardbreaks = FALSE, smart = FALSE, normalize = FA
 
 #' @export
 #' @rdname commonmark
-markdown_man <- function(text, hardbreaks = FALSE, smart = FALSE, normalize = FALSE){
+markdown_man <- function(text, hardbreaks = FALSE, smart = FALSE, normalize = FALSE, width = 0){
   text <- enc2utf8(paste(text, collapse="\n"))
-  .Call(R_render_markdown, text, 3L, FALSE, hardbreaks, smart, normalize, 0L)
+  .Call(R_render_markdown, text, 3L, FALSE, hardbreaks, smart, normalize, as.integer(width))
 }
 
 #' @export
@@ -49,3 +50,10 @@ markdown_commonmark <- function(text, hardbreaks = FALSE, smart = FALSE, normali
   text <- enc2utf8(paste(text, collapse="\n"))
   .Call(R_render_markdown, text, 4L, FALSE, hardbreaks, smart, normalize, as.integer(width))
 }
+
+#' @export
+#' @rdname commonmark
+markdown_latex <- function(text, hardbreaks = FALSE, smart = FALSE, normalize = FALSE, width = 0){
+  text <- enc2utf8(paste(text, collapse="\n"))
+  .Call(R_render_markdown, text, 5L, FALSE, hardbreaks, smart, normalize, as.integer(width))
+}
